pub struct FileUploadInput {
pub name: Option<String>,
pub filename: Option<String>,
pub content_type: Option<String>,
pub data: Vec<u8>,
}Expand description
File input schema used both for multipart-form uploads (in which case the name is mapped to column names) and JSON where the column name is extracted from the corresponding key of the parent object.
Fields
name: Option<String>The name of the form’s file control.
filename: Option<String>The file’s file name.
content_type: Option<String>The file’s content type.
data: Vec<u8>The file’s data
Implementations