pub struct TableMetadata {
pub schema: Table,
pub record_pk_column: Option<usize>,
pub user_id_columns: Vec<usize>,
pub json_metadata: JsonMetadata,
/* private fields */
}Expand description
A data class describing a sqlite Table and additional meta data useful for TrailBase.
An example of TrailBase idiosyncrasies are UUIDv7 columns, which are a bespoke concept.
Fields
schema: Tablerecord_pk_column: Option<usize>If and which column on this table qualifies as a record PK column, i.e. integer or UUIDv7.
user_id_columns: Vec<usize>If and which columns on this table reference _user(id).
json_metadata: JsonMetadataMetadata for CHECK(json_schema()) columns.
Implementations
Sourceimpl TableMetadata
impl TableMetadata
Sourcepub fn new(table: Table, tables: &[Table], user_table_name: &str) -> Self
pub fn new(table: Table, tables: &[Table], user_table_name: &str) -> Self
Build a new TableMetadata instance containing TrailBase/RecordApi specific information.
NOTE: The list of all tables is needed only to extract interger/UUIDv7 pk columns for foreign key relationships.
pub fn name(&self) -> &QualifiedName
pub fn column_index_by_name(&self, key: &str) -> Option<usize>
pub fn column_by_name(&self, key: &str) -> Option<(usize, &Column)>