pub struct ViewMetadata {
pub schema: View,
/* private fields */
}Expand description
A data class describing a sqlite View and future, additional meta data useful for TrailBase.
Fields
schema: ViewImplementations
Sourceimpl ViewMetadata
impl ViewMetadata
Sourcepub fn new(view: View, tables: &[Table]) -> Self
pub fn new(view: View, tables: &[Table]) -> Self
Build a new ViewMetadata instance containing TrailBase/RecordApi specific information.
NOTE: The list of all tables is needed only to extract interger/UUIDv7 pk columns for foreign key relationships.
pub fn name(&self) -> &QualifiedName
pub fn column_index_by_name(&self, key: &str) -> Option<usize>
pub fn column_by_name(&self, key: &str) -> Option<(usize, &Column)>